@@ -36,6 +36,8 @@ __all__ = (
     "CreateStreamProcessorResponseTypeDef",
     "DeleteCollectionResponseTypeDef",
     "DeleteFacesResponseTypeDef",
+    "DeleteProjectResponseTypeDef",
+    "DeleteProjectVersionResponseTypeDef",
     "DescribeCollectionResponseTypeDef",
     "S3ObjectTypeDef",
     "SummaryTypeDef",
@@ -253,6 +255,30 @@ DeleteFacesResponseTypeDef = TypedDict(
     "DeleteFacesResponseTypeDef", {"DeletedFaces": List[str]}, total=False
 )
 
+DeleteProjectResponseTypeDef = TypedDict(
+    "DeleteProjectResponseTypeDef",
+    {"Status": Literal["CREATING", "CREATED", "DELETING"]},
+    total=False,
+)
+
+DeleteProjectVersionResponseTypeDef = TypedDict(
+    "DeleteProjectVersionResponseTypeDef",
+    {
+        "Status": Literal[
+            "TRAINING_IN_PROGRESS",
+            "TRAINING_COMPLETED",
+            "TRAINING_FAILED",
+            "STARTING",
+            "RUNNING",
+            "FAILED",
+            "STOPPING",
+            "STOPPED",
+            "DELETING",
+        ]
+    },
+    total=False,
+)
+
 DescribeCollectionResponseTypeDef = TypedDict(
     "DescribeCollectionResponseTypeDef",
     {
